@@ -1,12 +1,11 @@
 """Mandatory (MUST) requirement checking functions
 """
 
-import collections
+from collections.abc import Mapping
 import re
 
 from cpe import CPE
 from dateutil import parser
-from six import string_types
 from stix2patterns.v20.pattern import Pattern
 from stix2patterns.validator import run_validator as pattern_validator
 
@@ -54,7 +53,7 @@ def timestamp(instance):
                                             % (obj['type'], tprop, obj[tprop], str(e)), instance['id'])
             if obj['type'] in enums.TIMESTAMP_EMBEDDED_PROPERTIES:
                 for embed in enums.TIMESTAMP_EMBEDDED_PROPERTIES[obj['type']]:
-                    if embed in obj and isinstance(obj[embed], collections.Mapping):
+                    if embed in obj and isinstance(obj[embed], Mapping):
                         for tprop in enums.TIMESTAMP_EMBEDDED_PROPERTIES[obj['type']][embed]:
                             if embed == 'extensions':
                                 for ext in obj[embed]:
@@ -329,7 +328,7 @@ def patterns(instance, options):
         return
 
     pattern = instance['pattern']
-    if not isinstance(pattern, string_types):
+    if not isinstance(pattern, str):
         return  # This error already caught by schemas
     errors = pattern_validator(pattern, stix_version='2.0')
 
